#!/usr/bin/python
# -*- coding: utf-8 -*-

from Screens.Screen import Screen
from Components.Label import Label
from Components.Sources.StaticText import StaticText
from Components.ActionMap import ActionMap
from enigma import getDesktop

sz_w = getDesktop(0).size().width()

class TestPluginScreenLabel(Screen):

	if sz_w == 1920:	#1920 x 1080 FHD
		skin = """
		<screen name="TestPluginScreenLabel" position="center,center" size="1220,680">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" size="300,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="300,0" size="300,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="600,0" size="300,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="900,0" size="300,70" scale="stretch" alphatest="on" />
			<widget source="key_red" render="Label" position="0,0" zPosition="1" size="300,70" font="Regular;30" halign="center" valign="center" foregroundColor="#ffffff" shadowColor="#000000" shadowOffset="-2,-2" backgroundColor="#9f1313" transparent="1" />
			<widget source="key_green" render="Label" position="300,0" zPosition="1" size="300,70" font="Regular;30" halign="center" valign="center" foregroundColor="#ffffff" shadowColor="#000000" shadowOffset="-2,-2" backgroundColor="#1f771f" transparent="1" />
			<widget source="key_yellow" render="Label" position="600,0" zPosition="1" size="300,70" font="Regular;30" foregroundColor="#ffffff" shadowColor="#000000" shadowOffset="-2,-2" halign="center" valign="center" backgroundColor="#a08500" transparent="1" />
			<widget source="key_blue" render="Label" position="900,0" zPosition="1" size="300,70" font="Regular;30" foregroundColor="#ffffff" shadowColor="#000000" shadowOffset="-2,-2" halign="center" valign="center" backgroundColor="#18188b" transparent="1" />
			<ePixmap pixmap="skin_default/div-h.png" position="0,531" zPosition="2" size="1200,2" />
			<widget name="orgLabel" zPosition="1" valign="center" backgroundColor="green" font="Regular;30" position="50,80" size="700,50" />
		</screen>"""
	else:
		# HD 1280720
		skin = """
		<screen name="TestPluginScreenLabel" position="center,center" size="800,500">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="200,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="400,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="600,0" size="200,40" scale="stretch" alphatest="on" />
			<widget source="key_red" render="Label" position="0,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" foregroundColor="#ffffff" shadowColor="#000000" shadowOffset="-2,-2"  backgroundColor="#9f1313" transparent="1" />
			<widget source="key_green" render="Label" position="200,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" foregroundColor="#ffffff" shadowColor="#000000" shadowOffset="-2,-2" backgroundColor="#1f771f" transparent="1" />
			<widget source="key_yellow" render="Label" position="400,0" zPosition="1" size="200,40" font="Regular;22" foregroundColor="#ffffff" shadowColor="#000000" shadowOffset="-2,-2" halign="center" valign="center" backgroundColor="#a08500" transparent="1" />
			<widget source="key_blue" render="Label" position="600,0" zPosition="1" size="200,40" font="Regular;22" foregroundColor="#ffffff" shadowColor="#000000" shadowOffset="-2,-2" halign="center" valign="center" backgroundColor="#18188b" transparent="1" />
			<ePixmap pixmap="skin_default/div-h.png" position="0,431" zPosition="2" size="800,2" />
			<widget name="orgLabel" zPosition="1" valign="center" backgroundColor="green" font="Regular;22" position="50,80" size="700,50" />
		</screen>"""
		
	def __init__(self, session):
		Screen.__init__(self, session)
		
		self.setTitle("TEST - live create Label on runtime")
		
		# Initialize widgets
		self["key_green"] = StaticText(_("create new"))
		self["key_red"] = StaticText(_("Cancel"))
		self["key_yellow"] = StaticText("copy org")
		self["key_blue"] = StaticText(" ")
		self["orgLabel"] = Label(" orgLabel")
		
		# Define Actions
		self["actions"] = ActionMap(["SetupActions", "ColorActions"],
			{
				"cancel": 	self.close,
				"green": 	self.pos1,
				"yellow": 	self.pos2,
				"blue":		self.pos3,
			},-2)
		
		self.onLayoutFinish.append(self.layoutFinished)
	
	
	def layoutFinished(self):
		try:
			pass
			
		except:
			import traceback, sys
			traceback.print_exc()
	
	
	def pos1(self):
		
		try:
			if not self.has_key("liveLabel1"):
				
				from enigma import eSize,ePoint, eWidget, gFont
				from Components.Label import Label
				from skin import parseColor
				
				self["liveLabel1"] = Label()
				self["liveLabel1"].GUIcreate(self.instance)
				self["liveLabel1"].instance.setBackgroundColor(parseColor("yellow"))
				self["liveLabel1"].instance.setForegroundColor(parseColor("black"))
				if sz_w == 1920:
					self["liveLabel1"].instance.setFont(gFont("Regular", 30))
				else:
					self["liveLabel1"].instance.setFont(gFont("Regular", 22))
				self["liveLabel1"].instance.setVAlign(self["liveLabel1"].instance.alignCenter)
				# valign-Opts: alignTop, alignCenter, alignBottom, alignCenterOrBottom
				self["liveLabel1"].instance.setHAlign(self["liveLabel1"].instance.alignLeft)
				# halign-Opts: alignLeft, alignCenter, alignRight, alignBlock, alignCenterOrRight
				self["liveLabel1"].instance.setCornerRadius(12)
				self["liveLabel1"].instance.setZPosition(50)
				self["liveLabel1"].instance.resize(eSize(700,50))
				self["liveLabel1"].instance.move(ePoint(50,150))
				self["liveLabel1"].setText(" liveLabel1 new")
			
		except:
			import traceback, sys
			traceback.print_exc()
			
	
	
	def pos2(self):
		try:
			if not self.has_key("liveLabel2"):

				from enigma import eSize,ePoint, eWidget
				from Components.Label import Label
				from skin import parseColor
				
				self["liveLabel2"] = Label()
				self["liveLabel2"].GUIcreate(self.instance)
				self["liveLabel2"].skinAttributes = self["orgLabel"].skinAttributes
				self["liveLabel2"].applySkin(getDesktop(0), self)
				self["liveLabel2"].instance.move(ePoint(50,220))
				self["liveLabel2"].setText(" liveLabel2 copy")
			
		except:
			import traceback
			traceback.print_exc()
	
	
	def pos3(self):
		try:
			pass
		
		except:
			import traceback
			traceback.print_exc()

